D00000.M.100.A.C

[1] BritishCCC authoritiesCCC arrestedCCC GeneralCCC AugustoCCC PinochetCCC inCCC LondonCCC forCCC backCCC surgeryCCC onCCC anCCC internationalCCC warrantCCC [2] issuedCCC byCCC SpanishCCC magistrateCCC BaltasarCCC GarzonCCC [3] TheCCC MadridCCC courtCCC chargedCCC PinochetCCC [4] whoCCC ruledCCC ChileCCC asCCC aCCC despotCCC forCCC yearsCCC [5] withCCC crimesCCC againstCCC humanityCCC [6] includingCCC genocideCCC andCCC terrorismCCC involvingCCC theCCC deathsCCC ofCCC moreCCC thanCCC peopleCCC [7] TheCCC ChileanCCC governmentCCC protestedCCC thatCCC PinochetCCC nowCCC aCCC hasCCC legalCCC immunityCCC [8] butCCC fewCCC inCCC ChileanCCC societyCCC protestedCCC theCCC arrestCCC [9] PinochetCCC arrestCCC showsCCC theCCC growingCCC significanceCCC ofCCC internationalCCC lawCCC [10] suggestingCCC thatCCC officialsCCC accusedCCC ofCCC atrocitiesCCC haveCCC fewerCCC placesCCC toCCC hideCCC theseCCC daysCCC [11] evenCCC ifCCC theyCCC areCCC carryingCCC diplomaticCCC passportsCCC